#!/usr/bin/env python3
# NOTE: Every dimension used here is of the form (width,height) rather than (height,width)!

__version__ = "0.1.1"

import argparse
from converter import Converter
from resizer import Resizer

parser = argparse.ArgumentParser(
    prog="imreco",
    description=f"Image Resize and Conversion. ({__version__})",
    formatter_class=lambda prog: argparse.HelpFormatter(prog,max_help_position=30)
)
parser.add_argument("function", help="Resize or Convert")
parser.add_argument("-s", "--size", help="Diamensions to new File", required=False)
parser.add_argument("-i", "--input", help="Input file")
parser.add_argument("-o", "--output", help="Output file")
args = parser.parse_args()

def main():
    if args.function == "resize":
        Resizer(args.input, args.output).resize(args.size)
    elif args.function == "convert":
        Converter(args.input, args.output).convert()
    else:
        print("Function not supported! Try resize/convert")

if __name__ == "__main__":
    main()




import cv2 as cv

class Converter:
    def __init__(self, input, output) -> None:
        self.input = input
        self.output = output

    def convert(self):
        old_format = self.input.split(".")[-1]
        img = cv.imread(self.input)
        cv.imwrite(self.output, img)
        new_format = self.output.split(".")[-1]

        print(f"Converted {old_format} to {new_format}")



from setuptools import setup

setup(
    name = 'imreco',
    packages = ['imreco'],
    version = '0.1.1',
    license = 'MIT',
    description = 'A cli program to resize images and convert between different formats.',
    long_description = "Read docs at https://github.com/tamton-aquib/imreco",
    author = 'aquib',
    author_email = 'aquibjavedt007@gmail.com',
    url = 'https://github.com/tamton-aquib/imreco',
    # download_url = 'https://github.com/tamton-aquib/imreco/archive/v_001.tar.gz',
    keywords = ['image', 'resizer', 'converter'],
    install_requires = [
        'opencv-python',
    ],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        ],
    )
